#!/usr/bin/perl
# $Id: afsdb.t,v 1.3 2001/10/25 22:36:14 eagle Exp $
#
# Test suite for the Stanford::LSDB::AFSDB module.  Before "make install" is
# performed this script should be runnable with "make test".

use strict;
use Test;

# Modify when adding new tests.
BEGIN { plan tests => 10 }

use Stanford::LSDB::AFSDB;

##############################################################################
# Test suite
##############################################################################

# (1) Try connecting to oracle-prod as the afsdb user.
my $dbh = Stanford::LSDB::AFSDB->connect;
ok (defined $dbh);

# (2) Ensure the database is there.
ok ($dbh->ping);

# (3) Create a table to test sqlldr.
ok ($dbh->do ('create table test1 (col1 varchar2(20), col2 number)'));

# (4) Test sqlldr.
open (DATA, '> tmp.dat') or die "Cannot create tmp.dat: $!\n";
print DATA "foo;7\nbarbaz;74\n";
close DATA;
open (CONTROL, '> tmp.ctl') or die "Cannot create tmp.ctl: $!\n";
print CONTROL <<'EOC';
load data
infile 'tmp.dat'
into table test1 insert
fields terminated by ';'
(col1, col2)
EOC
close CONTROL;
my $status = Stanford::LSDB::AFSDB->sqlldr ('tmp.ctl', 'tmp.log');
ok ($status == 0) or warn "sqlldr exited with status $status\n";
unlink ('tmp.ctl', 'tmp.log', 'tmp.dat');

# (5-7) Query the database to be sure that we get the same thing back again.
my $sth = $dbh->prepare ('select * from test1');
$sth->execute or die $sth->errstr;
my @row = $sth->fetchrow_array;
ok ("@row", 'foo 7');
@row = $sth->fetchrow_array;
ok ("@row", 'barbaz 74');
@row = $sth->fetchrow_array;
ok (!@row);

# (8,9) Drop the test table.
ok ($dbh->do ('truncate table test1'));
ok ($dbh->do ('drop table test1'));

# (10) Disconnect from the database.
ok ($dbh->disconnect) or warn $dbh->errstr;
